@@ -5,19 +5,11 @@ use crate::{
 use std::sync::Arc;
 
 /// A builder for an [`Agent`].
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct AgentBuilder {
     config: AgentConfig,
 }
 
-impl Default for AgentBuilder {
-    fn default() -> Self {
-        Self {
-            config: Default::default(),
-        }
-    }
-}
-
 impl AgentBuilder {
     /// Create an instance of [Agent] with the information from this builder.
     pub fn build(self) -> Result<Agent, AgentError> {
