@@ -17,14 +17,12 @@
  * limitations under the License.
  */
 
-use crate::bls::bls12381::big;
-use crate::bls::bls12381::big::BIG;
-use crate::bls::bls12381::fp;
-use crate::bls::bls12381::fp::FP;
-use crate::bls::bls12381::fp2::FP2;
 #[allow(unused_imports)]
 use crate::bls::bls12381::rom;
-use crate::bls::rand::RAND;
+use crate::bls::{
+    bls12381::{big, big::BIG, fp, fp::FP, fp2::FP2},
+    rand::RAND,
+};
 
 #[derive(Copy, Clone)]
 pub struct FP4 {
